[LON-CAPA-cvs] cvs: loncom /interface lonprintout.pm

raeburn lon-capa-cvs-allow@mail.lon-capa.org
Mon, 24 Mar 2008 18:22:37 -0000


raeburn		Mon Mar 24 14:22:37 2008 EDT

  Modified files:              
    /loncom/interface	lonprintout.pm 
  Log:
  - typo.
  - indicate the error was a network error.
  
  
Index: loncom/interface/lonprintout.pm
diff -u loncom/interface/lonprintout.pm:1.522 loncom/interface/lonprintout.pm:1.523
--- loncom/interface/lonprintout.pm:1.522	Sun Mar 23 15:48:49 2008
+++ loncom/interface/lonprintout.pm	Mon Mar 24 14:22:36 2008
@@ -1,7 +1,7 @@
 # The LearningOnline Network
 # Printout
 #
-# $Id: lonprintout.pm,v 1.522 2008/03/23 19:48:49 raeburn Exp $
+# $Id: lonprintout.pm,v 1.523 2008/03/24 18:22:36 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -116,7 +116,7 @@
 #                      the number of times requested by the caller.
 #                      If we still have a proble, no text is appended to the
 #                      output and we set some global variables.
 #                      to indicate to the caller an SSI error occured.  
 #                      All of this is supposed to deal with the issues described
 #                      in LonCAPA BZ 5631 see:
 #                      http://bugs.lon-capa.org/show_bug.cgi?id=5631
@@ -132,10 +132,10 @@
 #   On success, returns the rendered resource identified by the resource parameter.
 # Side Effects:
 #   The following global variables can be set:
 #    ssi_error                - If an unrecoverable error occured this becomes true.
 #                               It is up to the caller to initialize this to false
 #                               if desired.
 #    ssi_last_error_resource  - If an unrecoverable error occured, this is the value
 #                               of the resource that could not be rendered by the ssi
 #                               call.
 #    ssi_last_error           - The error string fetched from the ssi response
@@ -2097,7 +2097,7 @@
 	my $end_page = &Apache::loncommon::end_page();
 	$r->print('
 <br />
-<h2>'.&mt('An unrecoverable error occured:').'</h2>
+<h2>'.&mt('An unrecoverable network error occurred:').'</h2>
 <p>
   '.&mt('One of the resources ([_1]) you chose to print could not be rendered due to an unrecoverable error when communicating with a server:',$ssi_last_error_resource).' 
 <br />
@@ -116,7 +116,7 @@
 #                      If we still have a proble, no text is appended to the
 #                      output and we set some global variables.
-#                      to indicate to the caller an SSI error occured.  
+#                      to indicate to the caller an SSI error occurred.  
 #                      All of this is supposed to deal with the issues described
 #                      in LonCAPA BZ 5631 see:
@@ -132,10 +132,10 @@
 # Side Effects:
 #   The following global variables can be set:
-#    ssi_error                - If an unrecoverable error occured this becomes true.
+#    ssi_error                - If an unrecoverable error occurred this becomes true.
 #                               It is up to the caller to initialize this to false
 #                               if desired.
@@ -132,10 +132,10 @@
 #                               It is up to the caller to initialize this to false
 #                               if desired.
-#    ssi_last_error_resource  - If an unrecoverable error occured, this is the value
+#    ssi_last_error_resource  - If an unrecoverable error occurred, this is the value
 #                               of the resource that could not be rendered by the ssi
 #                               call.